/*
 * SPDX-FileCopyrightText: 2018 Bruce Cowan <bruce@bcowan.me.uk>
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <glib.h>

#include "array.h"

#define LENGTH 100

static Array *
create_array (size_t length)
{
    Array *array = array_new (g_free);

    for (size_t i = 0; i < length; i++)
    {
        gchar *str = g_strdup_printf ("String #%zu", i);
        array_add (array, str);
    }

    return array;
}

static void
test_get (void)
{
    Array *array = create_array (LENGTH);

    for (size_t i = 0; i < LENGTH; i++)
    {
        const gchar *element = (const gchar *) array_get (array, i);
        g_autofree gchar *compare = g_strdup_printf ("String #%zu", i);
        g_assert_cmpstr (element, ==, compare);
    }

    array_unref (array);
}

int
main (int    argc,
      char **argv)
{
    g_test_init (&argc, &argv, NULL);

    g_test_add_func ("/array/get", test_get);

    return g_test_run ();
}
