/*
 * SPDX-FileCopyrightText: 2018 Bruce Cowan <bruce@bcowan.me.uk>
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <glib.h>

#include "array.h"

static void
test_length (void)
{
    Array *array = array_new (NULL);

    size_t length = array_get_length (array);
    g_assert_cmpint (length, ==, 0);

    array_unref (array);
}

static void
test_remove_fast (void)
{
    Array *array = array_new (NULL);

    gboolean success = array_remove_fast (array, 1);
    g_assert_false (success);

    array_unref (array);
}

static void
test_remove (void)
{
    Array *array = array_new (NULL);

    gboolean success = array_remove (array, 1);
    g_assert_false (success);

    array_unref (array);
}

static void
test_get (void)
{
    Array *array = array_new (NULL);

    const void *element = array_get (array, 1);
    g_assert_null (element);

    array_unref (array);
}

static void
test_set (void)
{
    Array *array = array_new (NULL);

    gboolean success = array_set (array, 1, NULL);
    g_assert_false (success);

    array_unref (array);
}

int
main (int    argc,
      char **argv)
{
    g_test_init (&argc, &argv, NULL);

    g_test_add_func ("/array/length", test_length);
    g_test_add_func ("/array/remove_fast", test_remove_fast);
    g_test_add_func ("/array/remove", test_remove);
    g_test_add_func ("/array/get", test_get);
    g_test_add_func ("/array/set", test_set);

    return g_test_run ();
}
